Index: Scheduling/trunk/cs/bsdx0200GUISourceCode/CGView.cs
===================================================================
--- Scheduling/trunk/cs/bsdx0200GUISourceCode/CGView.cs	(revision 1125)
+++ Scheduling/trunk/cs/bsdx0200GUISourceCode/CGView.cs	(revision 1126)
@@ -3345,5 +3345,5 @@
             //Today's appointments
             var todaysAppts = (from lkappts in this.Document.Appointments.AppointmentTable.Values.Cast<CGAppointment>()
-                               where lkappts.StartTime > appt.StartTime.Date && lkappts.StartTime < appt.StartTime.AddDays(1).Date
+                               where lkappts.StartTime > appt.StartTime.Date && lkappts.StartTime < appt.StartTime.AddDays(1).Date && lkappts.Resource == appt.Resource
                               orderby lkappts.StartTime
                               select lkappts).ToList();
Index: Scheduling/trunk/cs/bsdx0200GUISourceCode/Printing.cs
===================================================================
--- Scheduling/trunk/cs/bsdx0200GUISourceCode/Printing.cs	(revision 1125)
+++ Scheduling/trunk/cs/bsdx0200GUISourceCode/Printing.cs	(revision 1126)
@@ -185,5 +185,5 @@
 
             //string s = "Appointment Reminder Slip";
-            string s = strings.ApptRoutingSlip;
+            string s = strings.ApptReminderSlip;
             g.DrawString(s, fTitle, Brushes.Black, printArea, sf); //title
 
Index: Scheduling/trunk/cs/bsdx0200GUISourceCode/strings.ar.resx
===================================================================
--- Scheduling/trunk/cs/bsdx0200GUISourceCode/strings.ar.resx	(revision 1125)
+++ Scheduling/trunk/cs/bsdx0200GUISourceCode/strings.ar.resx	(revision 1126)
@@ -127,5 +127,5 @@
     <value>تفاصيل الموعد</value>
   </data>
-  <data name="ApptRoutingSlip" xml:space="preserve">
+  <data name="ApptReminderSlip" xml:space="preserve">
     <value>بطاقة المراجعة</value>
   </data>
Index: Scheduling/trunk/cs/bsdx0200GUISourceCode/strings.resx
===================================================================
--- Scheduling/trunk/cs/bsdx0200GUISourceCode/strings.resx	(revision 1125)
+++ Scheduling/trunk/cs/bsdx0200GUISourceCode/strings.resx	(revision 1126)
@@ -127,6 +127,6 @@
     <value>Appointment Details</value>
   </data>
-  <data name="ApptRoutingSlip" xml:space="preserve">
-    <value>Appointment Routing Slip</value>
+  <data name="ApptReminderSlip" xml:space="preserve">
+    <value>Appointment Reminder Slip</value>
   </data>
   <data name="Clinic" xml:space="preserve">

Index: Scheduling/trunk/cs/bsdx0200GUISourceCode/strings.Designer.cs
===================================================================
--- Scheduling/trunk/cs/bsdx0200GUISourceCode/strings.Designer.cs	(revision 1125)
+++ Scheduling/trunk/cs/bsdx0200GUISourceCode/strings.Designer.cs	(revision 1126)
@@ -89,9 +89,9 @@
         
         /// <summary>
-        ///   Looks up a localized string similar to Appointment Routing Slip.
-        /// </summary>
-        internal static string ApptRoutingSlip {
-            get {
-                return ResourceManager.GetString("ApptRoutingSlip", resourceCulture);
+        ///   Looks up a localized string similar to Appointment Reminder Slip.
+        /// </summary>
+        internal static string ApptReminderSlip {
+            get {
+                return ResourceManager.GetString("ApptReminderSlip", resourceCulture);
             }
         }